/*
 * Copyright 2011 Chris de Vreeze
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package eu.cdevreeze.springjdbc

import scala.collection.immutable

/**
 * Typed query argument lists, used in the Scala `JdbcTemplate`. The types are integer constants from `java.sql.Types`.
 *
 * @author Chris de Vreeze
 */
final class TypedArgs(val typedArgs: immutable.Seq[TypedArg]) extends Immutable {

  require(typedArgs ne null)

  def args: immutable.Seq[AnyRef] = typedArgs map { _.argValue }
  def argTypes: immutable.Seq[Int] = typedArgs map { _.argType }

  def toArgArray: Array[AnyRef] = args.toArray
  def toArgTypeArray: Array[Int] = argTypes.toArray
}

object TypedArgs {

  def apply(typedArgs: TypedArg*): TypedArgs = {
    new TypedArgs(typedArgs.toIndexedSeq)
  }
}
