/*
 * Copyright 2011 Chris de Vreeze
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package eu.cdevreeze.springjdbc
package namedparam

import java.{ util => jutil }
import scala.collection.JavaConverters._

/**
 * Named query argument lists, used in the Scala `NamedParamJdbcTemplate`.
 *
 * @author Chris de Vreeze
 */
final class NamedArgs(val args: Map[String, AnyRef]) extends Immutable {

  require(args ne null)

  def toJavaMap: jutil.Map[String, AnyRef] = new jutil.HashMap[String, AnyRef](args.asJava)
}

object NamedArgs {

  def apply(args: (String, AnyRef)*): NamedArgs = new NamedArgs(args.toMap)
}
